@@ -5,13 +5,15 @@ set -o errexit  # Exit the script with error if any of the commands fail
 
 # Supported/used environment variables:
 #       RVM_RUBY      Define the Ruby version to test with, using its RVM identifier.
-#                     For example: "ruby-2.3" or "jruby-9.2"
+#                     For example: "ruby-2.4" or "jruby-9.2"
 
+. `dirname "$0"`/../spec/shared/shlib/distro.sh
+. `dirname "$0"`/../spec/shared/shlib/set_env.sh
 . `dirname "$0"`/functions.sh
 
 set_env_vars
 
-setup_ruby
+set_env_ruby
 
 install_deps
 
