@@ -30,6 +30,8 @@ const rb_data_type_t rb_byte_buffer_data_type = {
   { NULL, rb_bson_byte_buffer_free, rb_bson_byte_buffer_memsize }
 };
 
+VALUE _ref_str, _id_str, _db_str;
+
 /**
  * Initialize the bson_native extension.
  */
@@ -37,6 +39,13 @@ void Init_bson_native()
 {
   char rb_bson_machine_id[256];
 
+  _ref_str = rb_str_new_cstr("$ref");
+  rb_gc_register_mark_object(_ref_str);
+  _id_str = rb_str_new_cstr("$id");
+  rb_gc_register_mark_object(_id_str);
+  _db_str = rb_str_new_cstr("$db");
+  rb_gc_register_mark_object(_db_str);
+
   VALUE rb_bson_module = rb_define_module("BSON");
 
   /* Document-class: BSON::ByteBuffer
@@ -56,6 +65,16 @@ void Init_bson_native()
 
   rb_define_alloc_func(rb_byte_buffer_class, rb_bson_byte_buffer_allocate);
   rb_define_method(rb_byte_buffer_class, "initialize", rb_bson_byte_buffer_initialize, -1);
+
+  /*
+   * call-seq:
+   *   buffer.length -> Fixnum
+   *
+   * Returns the number of bytes available to be read in the buffer.
+   *
+   * When a buffer is being written to, each added byte increases its length.
+   * When a buffer is being read from, each read byte decreases its length.
+   */
   rb_define_method(rb_byte_buffer_class, "length", rb_bson_byte_buffer_length, 0);
 
   /*
@@ -266,7 +285,7 @@ void Init_bson_native()
 
   /*
    * call-seq:
-   *   buffer.put_hash(hash) -> ByteBuffer
+   *   buffer.put_hash(hash, validating_keys) -> ByteBuffer
    *
    * Writes a Hash into the byte buffer.
    *
@@ -319,6 +338,10 @@ void Init_bson_native()
    *
    * Returns the contents of the buffer as a binary string.
    *
+   * If the buffer is used for reading, the returned contents is the data
+   * that was not yet read. If the buffer is used for writing, the returned
+   * contents is the complete data that has been written so far.
+   *
    * Note: this method copies the buffer's contents into a newly allocated
    * +String+ instance. It does not return a reference to the data stored in
    * the buffer itself.
