@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,7 +28,7 @@ module BSON
     # A binary is type 0x05 in the BSON spec.
     #
     # @since 2.0.0
-    BSON_TYPE = 5.chr.force_encoding(BINARY).freeze
+    BSON_TYPE = ::String.new(5.chr, encoding: BINARY).freeze
 
     # The mappings of subtypes to their single byte identifiers.
     #
@@ -46,7 +47,8 @@ module BSON
       :uuid => 4.chr,
       :md5 => 5.chr,
       :ciphertext => 6.chr,
-      :user => 128.chr
+      :column => 7.chr,
+      :user => 128.chr,
     }.freeze
 
     # The mappings of single byte subtypes to their symbol counterparts.
@@ -169,7 +171,7 @@ module BSON
     #
     # @since 2.3.0
     def inspect
-      "<BSON::Binary:0x#{object_id} type=#{type} data=0x#{data[0, 8].unpack('H*').first}...>"
+      "<BSON::Binary:0x#{object_id} type=#{type} data=0x#{data[0, 8].unpack1('H*')}...>"
     end
 
     # Returns a string representation of the UUID stored in this Binary.
@@ -207,7 +209,8 @@ module BSON
         if representation && representation != :standard
           raise ArgumentError, "Binary of type :uuid can only be stringified to :standard representation, requested: #{representation.inspect}"
         end
-        data.split('').map { |n| '%02x' % n.ord }.join.sub(/(.{8})(.{4})(.{4})(.{12})/, '\1-\2-\3-\4')
+
+        data.split('').map { |n| '%02x' % n.ord }.join.sub(/\A(.{8})(.{4})(.{4})(.{4})(.{12})\z/, '\1-\2-\3-\4-\5')
       when :uuid_old
         if representation.nil?
           raise ArgumentError, 'Representation must be specified for BSON::Binary objects of type :uuid_old'
@@ -229,7 +232,7 @@ module BSON
           hex
         else
           raise ArgumentError, "Invalid representation: #{representation}"
-        end.sub(/(.{8})(.{4})(.{4})(.{12})/, '\1-\2-\3-\4')
+        end.sub(/\A(.{8})(.{4})(.{4})(.{4})(.{12})\z/, '\1-\2-\3-\4-\5')
       else
         raise TypeError, "The type of Binary must be :uuid or :uuid_old, this object is: #{type.inspect}"
       end
