@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # Copyright (C) 2016-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -19,36 +20,37 @@ module BSON
 
   class Decimal128
     include JSON
+    include Comparable
 
     # A Decimal128 is type 0x13 in the BSON spec.
     #
     # @since 4.2.0
-    BSON_TYPE = 19.chr.force_encoding(BINARY).freeze
+    BSON_TYPE = ::String.new(19.chr, encoding: BINARY).freeze
 
     # Exponent offset.
     #
     # @since 4.2.0
-    EXPONENT_OFFSET = 6176.freeze
+    EXPONENT_OFFSET = 6176
 
     # Minimum exponent.
     #
     # @since 4.2.0
-    MIN_EXPONENT = -6176.freeze
+    MIN_EXPONENT = -6176
 
     # Maximum exponent.
     #
     # @since 4.2.0
-    MAX_EXPONENT = 6111.freeze
+    MAX_EXPONENT = 6111
 
     # Maximum digits of precision.
     #
     # @since 4.2.0
-    MAX_DIGITS_OF_PRECISION = 34.freeze
+    MAX_DIGITS_OF_PRECISION = 34
 
     # Key for this type when converted to extended json.
     #
     # @since 4.2.0
-    EXTENDED_JSON_KEY = "$numberDecimal".freeze
+    EXTENDED_JSON_KEY = "$numberDecimal"
 
     # The native type to which this object can be converted.
     #
@@ -96,7 +98,16 @@ module BSON
     end
     alias :eql? :==
 
-    # Create a new Decimal128 from a BigDecimal.
+    def <=>(other)
+      to_big_decimal <=> case other
+        when Decimal128
+          other.to_big_decimal
+        else
+          other
+        end
+    end
+
+    # Create a new Decimal128 from a string or a BigDecimal instance.
     #
     # @example Create a Decimal128 from a BigDecimal.
     #   Decimal128.new(big_decimal)
@@ -104,7 +115,7 @@ module BSON
     # @param [ String, BigDecimal ] object The BigDecimal or String to use for
     #   instantiating a Decimal128.
     #
-    # @raise [ InvalidBigDecimal ] Raise error unless object argument is a BigDecimal.
+    # @raise [ InvalidArgument ] When argument is not a String or BigDecimal.
     #
     # @since 4.2.0
     def initialize(object)
@@ -262,7 +273,7 @@ module BSON
       # The custom error message for this error.
       #
       # @since 4.2.0
-      MESSAGE = 'A Decimal128 can only be created from a String or BigDecimal.'.freeze
+      MESSAGE = 'A Decimal128 can only be created from a String or BigDecimal.'
 
       # Get the custom error message for the exception.
       #
@@ -288,7 +299,7 @@ module BSON
       # The custom error message for this error.
       #
       # @since 4.2.0
-      MESSAGE = 'Invalid string format for creating a Decimal128 object.'.freeze
+      MESSAGE = 'Invalid string format for creating a Decimal128 object.'
 
       # Get the custom error message for the exception.
       #
@@ -303,9 +314,7 @@ module BSON
       end
     end
 
-    # Raised when the exponent or significand provided is outside the valid range.
-    #
-    # @api private
+    # Raised when the exponent is outside the valid range.
     #
     # @since 4.2.0
     class InvalidRange < RuntimeError
@@ -313,7 +322,8 @@ module BSON
       # The custom error message for this error.
       #
       # @since 4.2.0
-      MESSAGE = 'Value out of range for Decimal128 representation.'.freeze
+      # @deprecated
+      MESSAGE = 'Value out of range for Decimal128 representation.'
 
       # Get the custom error message for the exception.
       #
@@ -328,6 +338,21 @@ module BSON
       end
     end
 
+    # Raised when the significand provided is outside the valid range.
+    #
+    # @note This class derives from InvalidRange for backwards compatibility,
+    #   however when RUBY-1806 is implemented it should be changed to derive
+    #   from the base BSON exception class.
+    class UnrepresentablePrecision < InvalidRange
+
+      # Get the custom error message for the exception.
+      #
+      # @return [ String ] The error message.
+      def message
+        'The value contains too much precision for Decimal128 representation'
+      end
+    end
+
     Registry.register(BSON_TYPE, self)
   end
 end
