@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -269,27 +270,69 @@ module BSON
       end
     end
 
-    if instance_methods.include?(:slice)
-      # Slices a document to include only the given keys.
-      # Will normalize symbol keys into strings.
-      # (this method is backported from ActiveSupport::Hash)
-      #
-      # @example Get a document/hash with only the `name` and `age` fields present
-      #   document # => { _id: <ObjectId>, :name => 'John', :age => 30, :location => 'Earth' }
-      #   document.slice(:name, 'age') # => { name: 'John', age: 30 }
-      #   document.slice('name') # => { name: 'John' }
-      #   document.slice(:foo) # => nil
-      #
-      # @param [ Array<String, Symbol> ] *keys Keys, that will be kept in the resulting document
-      #
-      # @return [ BSON::Document ] The document with only the selected keys
-      #
-      # @since 4.3.1
-      def slice(*keys)
-        super(*keys.map{|key| convert_key(key)})
+    # Slices a document to include only the given keys.
+    # Will normalize symbol keys into strings.
+    # (this method is backported from ActiveSupport::Hash)
+    #
+    # @example Get a document/hash with only the `name` and `age` fields present
+    #   document # => { _id: <ObjectId>, :name => "John", :age => 30, :location => "Earth" }
+    #   document.slice(:name, 'age') # => { "name": "John", "age" => 30 }
+    #   document.slice('name') # => { "name" => "John" }
+    #   document.slice(:foo) # => {}
+    #
+    # @param [ Array<String, Symbol> ] *keys Keys, that will be kept in the resulting document
+    #
+    # @return [ BSON::Document ] The document with only the selected keys
+    #
+    # @since 4.3.1
+    def slice(*keys)
+      keys.each_with_object(self.class.new) do |key, hash|
+        if key?(key)
+          hash[key] = self[key]
+        end
       end
     end
 
+    # Returns a new document consisting of the current document minus the
+    # specified keys.
+    #
+    # The keys to be removed can be specified as either strings or symbols.
+    #
+    # @example Get a document/hash with only the `name` and `age` fields removed
+    #   document # => { _id: <ObjectId>, :name => 'John', :age => 30, :location => 'Earth' }
+    #   document.except(:name, 'age') # => { _id: <ObjectId>, location: 'Earth' }
+    #
+    # @param [ Array<String, Symbol> ] *keys Keys, that will be removed in the resulting document
+    #
+    # @return [ BSON::Document ] The document with the specified keys removed.
+    #
+    # @note This method is always defined, even if Hash already contains a
+    #   definition of #except, because ActiveSupport unconditionally defines
+    #   its version of #except which doesn't work for BSON::Document which
+    #   causes problems if ActiveSupport is loaded after bson-ruby is.
+    def except(*keys)
+      copy = dup
+      keys.each {|key| copy.delete(key)}
+      copy
+    end
+
+    def symbolize_keys!
+      raise ArgumentError, 'symbolize_keys! is not supported on BSON::Document instances. Please convert the document to hash first (using #to_h), then call #symbolize_keys! on the Hash instance'
+    end
+
+    # Override the Hash implementation of to_bson_normalized_value.
+    #
+    # BSON::Document is already of the correct type and already provides
+    # indifferent access to keys, hence no further conversions are necessary.
+    #
+    # Attempting to perform Hash's conversion on Document instances converts
+    # DBRefs to Documents which is wrong.
+    #
+    # @return [ BSON::Document ] The normalized hash.
+    def to_bson_normalized_value
+      self
+    end
+
     private
 
     def convert_key(key)
