@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module BSON
   # Base exception class for all BSON-related errors.
   #
@@ -23,5 +24,11 @@ module BSON
     # itself to BSON.
     class UnserializableClass < Error
     end
+
+    # Exception raised when there is an invalid argument passed into the
+    # constructor of regexp object. This includes when the argument contains
+    # a null byte.
+    class InvalidRegexpPattern < Error
+    end
   end
 end
