@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,7 +16,7 @@
 module BSON
 
   # Injects behaviour for encoding and decoding floating point values
-  # to and from # raw bytes as specified by the BSON spec.
+  # to and from raw bytes as specified by the BSON spec.
   #
   # @see http://bsonspec.org/#/specification
   #
@@ -25,12 +26,12 @@ module BSON
     # A floating point is type 0x01 in the BSON spec.
     #
     # @since 2.0.0
-    BSON_TYPE = 1.chr.force_encoding(BINARY).freeze
+    BSON_TYPE = ::String.new(1.chr, encoding: BINARY).freeze
 
     # The pack directive is for 8 byte floating points.
     #
     # @since 2.0.0
-    PACK = "E".freeze
+    PACK = "E"
 
     # Get the floating point as encoded BSON.
     #
@@ -57,36 +58,24 @@ module BSON
     #
     # @return [ Hash | Float ] The extended json representation.
     def as_extended_json(**options)
-      case infinite?
-      when 1
-        {'$numberDouble' => 'Infinity'}
-      when -1
-        {'$numberDouble' => '-Infinity'}
+      if infinite? == 1
+        { '$numberDouble' => 'Infinity' }
+      elsif infinite? == -1
+        { '$numberDouble' => '-Infinity' }
+      elsif nan?
+        { '$numberDouble' => 'NaN' }
+      elsif options[:mode] == :relaxed || options[:mode] == :legacy
+        self
+      elsif BSON::Environment.jruby? && abs > 1e15
+        # Hack to make bson corpus spec tests pass.
+        # JRuby serializes -1.2345678901234568e+18 as
+        # -1234567890123456770.0, which is valid but differs from MRI
+        # serialization. Extended JSON spec does not define precise
+        # stringification of floats.
+        # https://jira.mongodb.org/browse/SPEC-1536
+        { '$numberDouble' => ('%.17g' % to_s).upcase }
       else
-        if nan?
-          {'$numberDouble' => 'NaN'}
-        else
-          if options[:mode] == :relaxed || options[:mode] == :legacy
-            self
-          else
-            value = if BSON::Environment.jruby?
-              # Hack to make bson corpus spec tests pass.
-              # JRuby serializes -1.2345678901234568e+18 as
-              # -1234567890123456770.0, which is valid but differs from MRI
-              # serialization. Extended JSON spec does not define precise
-              # stringification of floats.
-              # https://jira.mongodb.org/browse/SPEC-1536
-              if abs > 1e15
-                '%.17g' % to_s
-              else
-                to_s
-              end
-            else
-              to_s
-            end
-            {'$numberDouble' => value.upcase}
-          end
-        end
+        { '$numberDouble' => to_s.upcase }
       end
     end
 
