@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,7 +26,7 @@ module BSON
     # A hash, also called an embedded document, is type 0x03 in the BSON spec.
     #
     # @since 2.0.0
-    BSON_TYPE = 3.chr.force_encoding(BINARY).freeze
+    BSON_TYPE = ::String.new(3.chr, encoding: BINARY).freeze
 
     # Get the hash as encoded BSON.
     #
@@ -70,7 +71,7 @@ module BSON
     # @example Convert the hash to a normalized value.
     #   hash.to_bson_normalized_value
     #
-    # @return [ BSON::Document ] The normazlied hash.
+    # @return [ BSON::Document ] The normalized hash.
     #
     # @since 3.0.0
     def to_bson_normalized_value
@@ -88,9 +89,7 @@ module BSON
     #
     # @return [ Hash ] This hash converted to extended json representation.
     def as_extended_json(**options)
-      ::Hash[map do |key, value|
-        [key, value.as_extended_json(**options)]
-      end]
+      transform_values { |value| value.as_extended_json(**options) }
     end
 
     module ClassMethods
@@ -101,7 +100,7 @@ module BSON
       #
       # @option options [ nil | :bson ] :mode Decoding mode to use.
       #
-      # @return [ Array ] The decoded hash.
+      # @return [ Hash ] The decoded hash.
       #
       # @see http://bsonspec.org/#/specification
       #
@@ -129,6 +128,16 @@ module BSON
           if actual_byte_size != expected_byte_size
             raise Error::BSONDecodeError, "Expected hash to take #{expected_byte_size} bytes but it took #{actual_byte_size} bytes"
           end
+
+          if hash['$ref'] && hash['$id']
+            # We're doing implicit decoding here. If the document is an invalid
+            # dbref, we should decode it as a BSON::Document.
+            begin
+              hash = DBRef.new(hash)
+            rescue ArgumentError
+            end
+          end
+
           hash
         end
       end
