@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -30,7 +31,7 @@ module BSON
     # A object_id is type 0x07 in the BSON spec.
     #
     # @since 2.0.0
-    BSON_TYPE = 7.chr.force_encoding(BINARY).freeze
+    BSON_TYPE = ::String.new(7.chr, encoding: BINARY).freeze
 
     # Check equality of the object id with another object.
     #
@@ -112,7 +113,7 @@ module BSON
     #
     # @since 2.0.0
     def generation_time
-      ::Time.at(generate_data.unpack("N")[0]).utc
+      ::Time.at(generate_data.unpack1("N")).utc
     end
     alias :to_time :generation_time
 
@@ -352,7 +353,7 @@ module BSON
       # @since 2.0.0
       def initialize
         @counter = rand(0x1000000)
-        @machine_id = Digest::MD5.digest(Socket.gethostname).unpack("N")[0]
+        @machine_id = Digest::MD5.digest(Socket.gethostname).unpack1("N")
         @mutex = Mutex.new
       end
 
