@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # Copyright (C) 2009-2020 MongoDB Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -39,7 +40,7 @@ module BSON
     # A time is type 0x09 in the BSON spec.
     #
     # @since 2.0.0
-    BSON_TYPE = 9.chr.force_encoding(BINARY).freeze
+    BSON_TYPE = ::String.new(9.chr, encoding: BINARY).freeze
 
     # Get the time as encoded BSON.
     #
@@ -63,8 +64,8 @@ module BSON
     #
     # @note The time is floored to the nearest millisecond.
     #
-    # @option options [ true | false ] :relaxed Whether to produce relaxed
-    #   extended JSON representation.
+    # @option opts [ nil | :relaxed | :legacy ] :mode Serialization mode
+    #   (default is canonical extended JSON)
     #
     # @return [ Hash ] The extended json representation.
     def as_extended_json(**options)
