@@ -215,6 +215,10 @@ describe BSON::Document do
 
       context "when provided string keys" do
 
+        it "is a BSON Document" do
+          expect(document.slice("key1")).to be_a(BSON::Document)
+        end
+
         it "returns the partial document" do
           expect(document.slice("key1")).to contain_exactly(['key1', 'value1'])
         end
@@ -222,13 +226,45 @@ describe BSON::Document do
 
       context "when provided symbol keys" do
 
+        it "is a BSON Document" do
+          expect(document.slice(:key1)).to be_a(BSON::Document)
+        end
+
         it "returns the partial document" do
           expect(document.slice(:key1)).to contain_exactly(['key1', 'value1'])
         end
       end
+
+      context "when provided keys that do not exist in the document" do
+
+        it "returns only the keys that exist in the document" do
+          expect(document.slice(:key1, :key3)).to contain_exactly(['key1', 'value1'])
+        end
+      end
     end
   end
 
+  describe "#except" do
+    let(:document) do
+      described_class.new("key1" => "value1", key2: "value2")
+    end
+
+    context "when provided string keys" do
+
+      it "returns the partial document" do
+        expect(document.except("key1")).to contain_exactly(['key2', 'value2'])
+      end
+    end
+
+    context "when provided symbol keys" do
+
+      it "returns the partial document" do
+        expect(document.except(:key1)).to contain_exactly(['key2', 'value2'])
+      end
+    end
+  end
+
+
   describe "#delete" do
 
     shared_examples_for "a document with deletable pairs" do
@@ -484,7 +520,13 @@ describe BSON::Document do
       context "when the document has been serialized" do
 
         let(:deserialized) do
-          YAML.load(YAML.dump(doc))
+          if YAML.respond_to?(:unsafe_load)
+            # In psych >= 4.0.0 `load` is basically an alias to `safe_load`,
+            # which will fail here.
+            YAML.unsafe_load(YAML.dump(doc))
+          else
+            YAML.load(YAML.dump(doc))
+          end
         end
 
         let!(:enum) do
