@@ -17,6 +17,7 @@ DRIVER_COMMON_BSON_TESTS = Dir.glob("#{CURRENT_PATH}/spec_tests/data/decimal128/
 BSON_CORPUS_TESTS = Dir.glob("#{CURRENT_PATH}/spec_tests/data/corpus/*.json").sort
 BSON_CORPUS_LEGACY_TESTS = Dir.glob("#{CURRENT_PATH}/spec_tests/data/corpus_legacy/*.json").sort
 
+$LOAD_PATH.unshift(File.join(File.dirname(__FILE__), "shared", "lib"))
 $LOAD_PATH.unshift(File.dirname(__FILE__))
 $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), "..", "lib"))
 
@@ -29,6 +30,13 @@ require "yaml"
 require 'support/spec_config'
 
 if SpecConfig.instance.active_support?
+  require "active_support/version"
+  if ActiveSupport.version >= Gem::Version.new(7)
+    # ActiveSupport wants us to require ALL of it all of the time.
+    # See: https://github.com/rails/rails/issues/43851,
+    # https://github.com/rails/rails/issues/43889, etc.
+    require 'active_support'
+  end
   require "active_support/time"
   require 'bson/active_support'
 end
@@ -40,6 +48,16 @@ unless ENV['CI'] || BSON::Environment.jruby?
   end
 end
 
+begin
+  require 'mrss/lite_constraints'
+rescue LoadError => exc
+  raise LoadError.new <<~MSG.strip
+    The test suite requires shared tooling to be installed.
+      Please refer to spec/README.md for instructions.
+    #{exc.class}: #{exc}
+  MSG
+end
+
 Dir["./spec/support/**/*.rb"].each { |file| require file }
 
 # Alternate IO class that returns a String from #readbyte.
@@ -71,4 +89,6 @@ RSpec.configure do |config|
       end
     end
   end
+
+  config.extend Mrss::LiteConstraints
 end
